Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: tools/create_sdk.py

Issue 10332109: Make the crypto library an official dart:crypto library. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix long line Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/lib/crypto/sha256_test.dart ('k') | utils/apidoc/apidoc.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/create_sdk.py
diff --git a/tools/create_sdk.py b/tools/create_sdk.py
index 5881e2a2ed4e4eb8da60d6c4e8c9978dc88f6a9e..e66788323e5a9e678acfea7353680b6257a5873d 100755
--- a/tools/create_sdk.py
+++ b/tools/create_sdk.py
@@ -42,6 +42,9 @@
# ......html/
# ........html_frog.dart
# ........html_dartium.dart
+# ......crypto/
+# ........crypto.dart
+# ........(implementation files)
# ......json/
# ........json_frog.dart
#.........json.dart
@@ -350,10 +353,10 @@ def Main(argv):
join(dom_dest_dir, 'dom_frog.dart'))
#
# Create and populate lib/{json, uri, utf} .
#
- for library in ['json', 'uri', 'utf']:
+ for library in ['crypto', 'json', 'uri', 'utf']:
src_dir = join(HOME, 'lib', library)
dest_dir = join(LIB, library)
os.makedirs(dest_dir)
@@ -350,10 +353,10 @@ def Main(argv):
join(dom_dest_dir, 'dom_frog.dart'))
#
- # Create and populate lib/{json, uri, utf} .
+ # Create and populate lib/{crypto, json, uri, utf}.
#
« no previous file with comments | « tests/lib/crypto/sha256_test.dart ('k') | utils/apidoc/apidoc.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698